@@ -1,4 +1,4 @@
-{- Copyright (c) 2013 John Lenz
+{- Copyright (c) 2014 John Lenz
 
 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
@@ -395,12 +395,11 @@ data NewAccountData = NewAccountData {
 -- form into a larger form where you prompt for more information during account
 -- creation.  In this case, the NewAccountData should be passed to 'createNewAccount'
 -- from inside 'postNewAccountR'.
-newAccountForm :: (YesodAuth master
-                  , RenderMessage master FormMessage
+newAccountForm :: (YesodAuthAccount db master
                   , MonadHandler m
                   , HandlerSite m ~ master
                   ) => AForm m NewAccountData
-newAccountForm = NewAccountData <$> areq textField userSettings Nothing
+newAccountForm = NewAccountData <$> areq (checkM checkValidUsername textField) userSettings Nothing
                                 <*> areq emailField emailSettings Nothing
                                 <*> areq passwordField pwdSettings1 Nothing
                                 <*> areq passwordField pwdSettings2 Nothing
@@ -410,7 +409,7 @@ newAccountForm = NewAccountData <$> areq textField userSettings Nothing
           pwdSettings2  = FieldSettings (SomeMessage Msg.ConfirmPass) Nothing Nothing Nothing []
 
 -- | A default rendering of the 'newAccountForm' using renderDivs.
-newAccountWidget :: (YesodAuth master, RenderMessage master FormMessage) => (Route Auth -> Route master) -> WidgetT master IO ()
+newAccountWidget :: YesodAuthAccount db master => (Route Auth -> Route master) -> WidgetT master IO ()
 newAccountWidget tm = do
     ((_,widget), enctype) <- liftHandlerT $ runFormPost $ renderDivs newAccountForm
     [whamlet|
@@ -932,7 +931,7 @@ data PersistFuncs master user = PersistFuncs {
 
 -- | A newtype which when using persistent is an instance of 'AccountDB'.
 newtype AccountPersistDB master user a = AccountPersistDB (ReaderT (PersistFuncs master user) (HandlerT master IO) a)
-    deriving (Monad, MonadIO)
+    deriving (Monad, MonadIO, Functor, Applicative)
 
 instance (Yesod master, PersistUserCredentials user) => AccountDB (AccountPersistDB master user) where
     type UserAccount (AccountPersistDB master user) = P.Entity user
